from setuptools import setup, find_packages

setup(
    name="ace2ryahee",
    version="1.1.1",  # Increment version
    packages=find_packages(), # This automatically finds 'dapu' as a sub-package
    entry_points={
        "console_scripts": [
            "ace2ryahee=ace2ryahee.main:main",
        ],
    },
)

